@@ -19,10 +19,17 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListRetainedMessagesPaginatorName", "ServiceName", "PaginatorName")
+__all__ = (
+    "ListRetainedMessagesPaginatorName",
+    "IoTDataPlaneServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+    "PaginatorName",
+)
 
 
 ListRetainedMessagesPaginatorName = Literal["list_retained_messages"]
+IoTDataPlaneServiceName = Literal["iot-data"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -54,6 +61,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -176,6 +184,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -324,4 +333,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_retained_messages"]
