@@ -6,14 +6,15 @@ Type annotations for iot-data service client paginators.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
 
-    from mypy_boto3_iot_data import IoTDataPlaneClient
+    from mypy_boto3_iot_data.client import IoTDataPlaneClient
     from mypy_boto3_iot_data.paginator import (
         ListRetainedMessagesPaginator,
     )
 
-    client: IoTDataPlaneClient = boto3.client("iot-data")
+    session = Session()
+    client: IoTDataPlaneClient = session.client("iot-data")
 
     list_retained_messages_paginator: ListRetainedMessagesPaginator = client.get_paginator("list_retained_messages")
     ```
@@ -40,7 +41,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListRetainedMessagesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/paginators.html#listretainedmessagespaginator)
     """
 
@@ -48,6 +49,6 @@ class ListRetainedMessagesPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRetainedMessagesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/paginators.html#listretainedmessagespaginator)
         """
