@@ -15,6 +15,7 @@ import sys
 from typing import IO, Dict, List, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -41,26 +42,13 @@ __all__ = (
     "UpdateThingShadowResponseTypeDef",
 )
 
-_RequiredDeleteThingShadowRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteThingShadowRequestRequestTypeDef",
+DeleteThingShadowRequestRequestTypeDef = TypedDict(
+    "DeleteThingShadowRequestRequestTypeDef",
     {
         "thingName": str,
+        "shadowName": NotRequired[str],
     },
 )
-_OptionalDeleteThingShadowRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteThingShadowRequestRequestTypeDef",
-    {
-        "shadowName": str,
-    },
-    total=False,
-)
-
-
-class DeleteThingShadowRequestRequestTypeDef(
-    _RequiredDeleteThingShadowRequestRequestTypeDef, _OptionalDeleteThingShadowRequestRequestTypeDef
-):
-    pass
-
 
 DeleteThingShadowResponseTypeDef = TypedDict(
     "DeleteThingShadowResponseTypeDef",
@@ -88,26 +76,13 @@ GetRetainedMessageResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetThingShadowRequestRequestTypeDef = TypedDict(
-    "_RequiredGetThingShadowRequestRequestTypeDef",
+GetThingShadowRequestRequestTypeDef = TypedDict(
+    "GetThingShadowRequestRequestTypeDef",
     {
         "thingName": str,
+        "shadowName": NotRequired[str],
     },
 )
-_OptionalGetThingShadowRequestRequestTypeDef = TypedDict(
-    "_OptionalGetThingShadowRequestRequestTypeDef",
-    {
-        "shadowName": str,
-    },
-    total=False,
-)
-
-
-class GetThingShadowRequestRequestTypeDef(
-    _RequiredGetThingShadowRequestRequestTypeDef, _OptionalGetThingShadowRequestRequestTypeDef
-):
-    pass
-
 
 GetThingShadowResponseTypeDef = TypedDict(
     "GetThingShadowResponseTypeDef",
@@ -117,28 +92,14 @@ GetThingShadowResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListNamedShadowsForThingRequestRequestTypeDef = TypedDict(
-    "_RequiredListNamedShadowsForThingRequestRequestTypeDef",
+ListNamedShadowsForThingRequestRequestTypeDef = TypedDict(
+    "ListNamedShadowsForThingRequestRequestTypeDef",
     {
         "thingName": str,
+        "nextToken": NotRequired[str],
+        "pageSize": NotRequired[int],
     },
 )
-_OptionalListNamedShadowsForThingRequestRequestTypeDef = TypedDict(
-    "_OptionalListNamedShadowsForThingRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "pageSize": int,
-    },
-    total=False,
-)
-
-
-class ListNamedShadowsForThingRequestRequestTypeDef(
-    _RequiredListNamedShadowsForThingRequestRequestTypeDef,
-    _OptionalListNamedShadowsForThingRequestRequestTypeDef,
-):
-    pass
-
 
 ListNamedShadowsForThingResponseTypeDef = TypedDict(
     "ListNamedShadowsForThingResponseTypeDef",
@@ -153,10 +114,9 @@ ListNamedShadowsForThingResponseTypeDef = TypedDict(
 ListRetainedMessagesRequestRequestTypeDef = TypedDict(
     "ListRetainedMessagesRequestRequestTypeDef",
     {
-        "nextToken": str,
-        "maxResults": int,
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListRetainedMessagesResponseTypeDef = TypedDict(
@@ -171,35 +131,21 @@ ListRetainedMessagesResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredPublishRequestRequestTypeDef = TypedDict(
-    "_RequiredPublishRequestRequestTypeDef",
+PublishRequestRequestTypeDef = TypedDict(
+    "PublishRequestRequestTypeDef",
     {
         "topic": str,
+        "qos": NotRequired[int],
+        "retain": NotRequired[bool],
+        "payload": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
     },
 )
-_OptionalPublishRequestRequestTypeDef = TypedDict(
-    "_OptionalPublishRequestRequestTypeDef",
-    {
-        "qos": int,
-        "retain": bool,
-        "payload": Union[bytes, IO[bytes], StreamingBody],
-    },
-    total=False,
-)
-
-
-class PublishRequestRequestTypeDef(
-    _RequiredPublishRequestRequestTypeDef, _OptionalPublishRequestRequestTypeDef
-):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -215,35 +161,21 @@ ResponseMetadataTypeDef = TypedDict(
 RetainedMessageSummaryTypeDef = TypedDict(
     "RetainedMessageSummaryTypeDef",
     {
-        "topic": str,
-        "payloadSize": int,
-        "qos": int,
-        "lastModifiedTime": int,
+        "topic": NotRequired[str],
+        "payloadSize": NotRequired[int],
+        "qos": NotRequired[int],
+        "lastModifiedTime": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredUpdateThingShadowRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateThingShadowRequestRequestTypeDef",
+UpdateThingShadowRequestRequestTypeDef = TypedDict(
+    "UpdateThingShadowRequestRequestTypeDef",
     {
         "thingName": str,
         "payload": Union[bytes, IO[bytes], StreamingBody],
+        "shadowName": NotRequired[str],
     },
 )
-_OptionalUpdateThingShadowRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateThingShadowRequestRequestTypeDef",
-    {
-        "shadowName": str,
-    },
-    total=False,
-)
-
-
-class UpdateThingShadowRequestRequestTypeDef(
-    _RequiredUpdateThingShadowRequestRequestTypeDef, _OptionalUpdateThingShadowRequestRequestTypeDef
-):
-    pass
-
 
 UpdateThingShadowResponseTypeDef = TypedDict(
     "UpdateThingShadowResponseTypeDef",
